@@ -23,12 +23,12 @@
 #include "abstractbackend.h"
 #include "debug_p.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QRect>
+#include <QDebug>
+#include <QRect>
 
 using namespace KScreen;
 
-class Config::Private : public QObject
+class Q_DECL_HIDDEN Config::Private : public QObject
 {
     Q_OBJECT
 public:
